#
# spec file for package python-PyWavelets
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-PyWavelets
Version:        1.0.1
Release:        2.11
Summary:        PyWavelets is a Python wavelet transforms module
License:        MIT
Group:          Development/Libraries/Python
URL:            http://pypi.python.org/pypi/PyWavelets/
Source0:        https://files.pythonhosted.org/packages/source/P/PyWavelets/PyWavelets-%{version}.tar.gz
Source10:       https://media.readthedocs.org/pdf/pywavelets/v%{version}/pywavelets.pdf
Source11:       https://media.readthedocs.org/htmlzip/pywavelets/v%{version}/pywavelets.zip
BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module nose}
BuildRequires:  %{python_module numpy-devel >= 1.9.1}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  unzip
Requires:       python-numpy >= 1.9.1
%python_subpackages

%description
PyWavelets is a Python wavelet transforms module that can do:

  * 1D and 2D Forward and Inverse Discrete Wavelet Transform (DWT and IDWT)
  * 1D and 2D Stationary Wavelet Transform (Undecimated Wavelet Transform)
  * 1D and 2D Wavelet Packet decomposition and reconstruction
  * Computing Approximations of wavelet and scaling functions
  * Over seventy built-in wavelet filters and support for custom wavelets
  * Single and double precision calculations
  * Results compatibility with Matlab Wavelet Toolbox

%package     -n %{name}-doc
Summary:        This package contains the HMTL documentation of %{name}
Group:          Documentation/Other
Provides:       %{python_module PyWavelets-doc = %{version}}

%description -n %{name}-doc
PyWavelets is a Python wavelet transforms module that can do:

  * 1D and 2D Forward and Inverse Discrete Wavelet Transform (DWT and IDWT)
  * 1D and 2D Stationary Wavelet Transform (Undecimated Wavelet Transform)
  * 1D and 2D Wavelet Packet decomposition and reconstruction
  * Computing Approximations of wavelet and scaling functions
  * Over seventy built-in wavelet filters and support for custom wavelets
  * Single and double precision calculations
  * Results compatibility with Matlab Wavelet Toolbox

This Package contains the documentation of %{name} in HTML and PDF formats.

%prep
%setup -q -n PyWavelets-%{version}
sed -i -e '/^#!\//, 1d' pywt/tests/*.py

cp %{SOURCE10} .
unzip %{SOURCE11} -d docs
mv docs/pywavelets-* docs/html
rm docs/html/.buildinfo

# Make docs non-executable
chmod a-x *.rst
chmod a-x PyWavelets.egg-info/*

# Fix wrong-script-interpreter
find demo -name '*.py' -exec sed -i "s|#!%{_bindir}/env python|#!%__python3|"  {} \;

# Remove unneeded shebangs
sed -i '1{\@^#!%{_bindir}/env python@d}' pywt/data/create_dat.py

# Remove unneeded executable bits
for lib in test_concurrent test_data test_deprecations test_doc test_matlab_compatibility test_matlab_compatibility_cwt test_thresholding data/generate_matlab_data data/generate_matlab_data_cwt ; do
   chmod a-x pywt/tests/$lib.py
done

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
%python_build

%install
%python_install

%{python_expand pushd %{buildroot}%{$python_sitearch}
# Fix wrong-script-interpreter
sed -i "s|#!%{_bindir}/env python|#!%__$python|" pywt/tests/*.py
# Deduplicating files can generate a RPMLINT warning for pyc mtime
$python -m compileall -d %{$python_sitearch} pywt/tests/
$python -O -m compileall -d %{$python_sitearch} pywt/tests/
%fdupes .
popd
}

%check
mkdir test
pushd test
%{python_expand export PYTHONPATH=%{buildroot}%{$python_sitearch}
$python -B -c 'import pywt;pywt.test()'
}

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitearch}/pywt/
%{python_sitearch}/PyWavelets-%{version}-py*.egg-info

%files -n %{name}-doc
%license LICENSE
%doc pywavelets.pdf
%doc docs/html

%changelog
* Fri Jan  4 2019 toddrme2178@gmail.com
- Update to version 1.0.1
  * Key-based assignment of coefficients to a ``FswavedecnResult`` object (i.e. via
    its __setitem__ method) has been fixed.
  * The order that the individual subband coefficients were stacked by the
    function ``pywt.ravel_coeffs`` is now guaranteed to be consistent across all
    supported Python versions. Explicit alphabetic ordering of subband coefficient
    names is used for consitent ordering regardless of Python version
- Update to version 1.0.0
  + New features
  * New 1D test signals
  * C99 complex support
  * complex-valued CWT
  * More flexible specification of some continuous wavelets
  * Fully Separable Discrete Wavelet Transfrom
  * New thresholding methods
  * New anti-symmetric boundary modes
  * New functions to ravel and unravel wavedecn coefficients
  * New functions to determine multilevel DWT coefficient shapes and sizes
  + Deprecated features
  * The continous wavelets with names ``"cmor"``, ``"shan"`` and ``"fbsp"``
    should now be modified to include formerly hard-coded attributes such as their
    center frequency and bandwidth. Use of the bare names "cmor". "shan" and
    "fbsp"  is now deprecated. For "cmor" (and "shan"), the form of the wavelet
    name is now "cmorB-C" ("shanB-C") where B and C are floats representing the
    bandwidth frequency and center frequency. For "fbsp" the form should now
    incorporate three floats as in "fbspM-B-C" where M is the spline order and B
    and C are the bandwidth and center frequencies.
  + Backwards incompatible changes
  * Python 2.6, 3.3 and 3.4 are no longer supported.
  * The order of coefficients returned by ``swt2`` and input to ``iswt2`` have been
    reversed so that the decomposition levels are now returned in descending rather
    than ascending order. This makes these 2D stationary wavelet functions
    consistent with all of the other multilevel discrete transforms in PyWavelets.
  * For ``wavedec``, ``wavedec2`` and ``wavedecn``, the ability for the user to
    specify a ``level`` that is greater than the value returned by
    ``dwt_max_level``  has been restored. A ``UserWarning`` is raised instead of a
    ``ValueError`` in this case.
  + Bugs Fixed
  * Assigning new data to the ``Node`` or ``Node2D`` no longer forces a cast to
    ``float64`` when the data is one of the other dtypes supported by the dwt
    (``float32``, ``complex64``, ``complex128``).
  * Calling ``pywt.threshold`` with ``mode='soft'`` now works properly for
    complex-valued inputs.
  * A segfault when running multiple `swt2` or `swtn` transforms concurrently has
    been fixed.
  * Several instances of deprecated numpy multi-indexing that caused warnings in
    numpy >=1.15 have been resolved.
  * The 2d inverse stationary wavelet transform, `iswt2`, now supports non-square
    inputs (an unnecessary check for square inputs was removed).
  * Wavelet packets no longer convert float32 to float64 upon assignment to nodes.
  * Doctests have been updated to also work with NumPy >= 1.14,
  * Indexing conventions have been updated to avoid FutureWarnings in NumPy 1.15.
  + Other changes
  * Python 3.7 is now officially supported.
- Remove upstream-included add_default_to_switch_statement.patch
* Wed Jul 18 2018 tchvatal@suse.com
- Stricten numpy dependency
* Sun Aug  6 2017 toddrme2178@gmail.com
- Fix shebangs
* Wed May 24 2017 toddrme2178@gmail.com
- Implement single-spec version
- Fix source URL
- Update to version 0.5.2
  Highlights:
  * 1D, 2D and nD Forward and Inverse Discrete Wavelet Transform
    (DWT and IDWT)
  * 1D, 2D and nD Multilevel DWT and IDWT
  * 1D and 2D Forward and Inverse Stationary Wavelet Transform
  * 1D and 2D Wavelet Packet decomposition and reconstruction
  * 1D Continuous Wavelet Transform
  * When multiple valid implementations are available, we have
    chosen to maintain consistency with |MATLAB|'s Wavelet Toolbox.
- Add add_default_to_switch_statement.patch
  Fixes no-return-in-nonvoid-function error
  From: https://github.com/PyWavelets/pywt/commit/91b0a7bdbdd181bfb765246a9ec949b1cf2d12ad
* Mon Jan 11 2016 toddrme2178@gmail.com
- Update to 0.4.0
  + Highlights:
  * 1D and 2D inverse stationary wavelet transforms
  * Substantially faster 2D and nD discrete wavelet transforms
  * Complex number support
  * nD versions of the multilevel DWT and IDWT
- Update to 0.3.0
  + Highlights:
  * Support for Python 3.x (>=3.3)
  * Added a test suite
    (based on nose, coverage up to 61%% so far)
  * Maintenance work: C style complying to the Numpy style guide,
    improved templating system, more complete docstrings,
    pep8/pyflakes compliance, and more.
* Thu Oct 24 2013 toddrme2178@gmail.com
- Update to 0.2.2
  * Bugfixes
* Wed Jun 13 2012 scorot@free.fr
- use proper python command instead of %%%%{__python} macro
- remove -O1 and --skip-build flags from the install command line
* Wed Jun 13 2012 scorot@free.fr
- first package
